@@ -7,7 +7,7 @@ module Licensee
       # a lenient regex for speed and security. Moar parsing moar problems.
       LICENSE_REGEX = /
         \s*["']license["']\s*:\s*['"]([a-z\-0-9.+ ()]+)['"],?\s*
-      /ix.freeze
+      /ix
 
       private
 
