@@ -9,8 +9,8 @@ module Licensee
         /\AREADME\.(#{Regexp.union(EXTENSIONS).source})\z/i => 0.9
       }.freeze
 
-      TITLE_REGEX = /licen[sc]e:?/i.freeze
-      UNDERLINE_REGEX = /\n[-=]+/m.freeze
+      TITLE_REGEX = /licen[sc]e:?/i
+      UNDERLINE_REGEX = /\n[-=]+/m
       CONTENT_REGEX = /^
           (?:                                # Header lookbehind
             [\#=]+\s#{TITLE_REGEX}\s*[\#=]*  # Start of hashes or rdoc header
@@ -27,7 +27,7 @@ module Licensee
           |
             \z                               # End of file
           )
-        /mix.freeze
+        /mix
 
       def possible_matchers
         super.push(Matchers::Reference)
