@@ -43,7 +43,7 @@ module Licensee
       end
 
       def raw_rules
-        YAML.safe_load File.read(Rule.file_path)
+        YAML.safe_load_file(Rule.file_path)
       end
 
       def groups
